@@ -6,6 +6,8 @@ from .helpers.kafka_producer import Producer
 from .helpers.topics import Topics
 from .helpers.micro_fetcher import MicroFetcher
 from .helpers.atomic_transactions import Transactions
+from .helpers.auth import Auth
+from .helpers.enums import Service
 
 __all__ = [
     "WeDeliverCore",
@@ -16,4 +18,6 @@ __all__ = [
     "Topics",
     "MicroFetcher",
     "Transactions",
+    "Service",
+    "Auth",
 ]
